==> coreutils-5.0-i486-4.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf [ )
( cd usr/bin ; ln -sf test [ )
( cd usr/bin ; rm -rf dd )
( cd usr/bin ; ln -sf ../../bin/dd dd )
( cd usr/bin ; rm -rf cp )
( cd usr/bin ; ln -sf ../../bin/cp cp )
( cd usr/bin ; rm -rf df )
( cd usr/bin ; ln -sf ../../bin/df df )
( cd usr/bin ; rm -rf du )
( cd usr/bin ; ln -sf ../../bin/du du )
( cd usr/bin ; rm -rf ln )
( cd usr/bin ; ln -sf ../../bin/ln ln )
( cd usr/bin ; rm -rf ls )
( cd usr/bin ; ln -sf ../../bin/ls ls )
( cd usr/bin ; rm -rf mv )
( cd usr/bin ; ln -sf ../../bin/mv mv )
( cd usr/bin ; rm -rf rm )
( cd usr/bin ; ln -sf ../../bin/rm rm )
( cd usr/bin ; rm -rf cat )
( cd usr/bin ; ln -sf ../../bin/cat cat )
( cd usr/bin ; rm -rf cut )
( cd usr/bin ; ln -sf ../../bin/cut cut )
( cd usr/bin ; rm -rf pwd )
( cd usr/bin ; ln -sf ../../bin/pwd pwd )
( cd usr/bin ; rm -rf ginstall )
( cd usr/bin ; ln -sf install ginstall )
( cd usr/bin ; rm -rf date )
( cd usr/bin ; ln -sf ../../bin/date date )
( cd usr/bin ; rm -rf echo )
( cd usr/bin ; ln -sf ../../bin/echo echo )
( cd usr/bin ; rm -rf head )
( cd usr/bin ; ln -sf ../../bin/head head )
( cd usr/bin ; rm -rf stty )
( cd usr/bin ; ln -sf ../../bin/stty stty )
( cd usr/bin ; rm -rf sync )
( cd usr/bin ; ln -sf ../../bin/sync sync )
( cd usr/bin ; rm -rf true )
( cd usr/bin ; ln -sf ../../bin/true true )
( cd usr/bin ; rm -rf chgrp )
( cd usr/bin ; ln -sf ../../bin/chgrp chgrp )
( cd usr/bin ; rm -rf chmod )
( cd usr/bin ; ln -sf ../../bin/chmod chmod )
( cd usr/bin ; rm -rf chown )
( cd usr/bin ; ln -sf ../../bin/chown chown )
( cd usr/bin ; rm -rf false )
( cd usr/bin ; ln -sf ../../bin/false false )
( cd usr/bin ; rm -rf mkdir )
( cd usr/bin ; ln -sf ../../bin/mkdir mkdir )
( cd usr/bin ; rm -rf mknod )
( cd usr/bin ; ln -sf ../../bin/mknod mknod )
( cd usr/bin ; rm -rf rmdir )
( cd usr/bin ; ln -sf ../../bin/rmdir rmdir )
( cd usr/bin ; rm -rf shred )
( cd usr/bin ; ln -sf ../../bin/shred shred )
( cd usr/bin ; rm -rf sleep )
( cd usr/bin ; ln -sf ../../bin/sleep sleep )
( cd usr/bin ; rm -rf touch )
( cd usr/bin ; ln -sf ../../bin/touch touch )
( cd usr/bin ; rm -rf uname )
( cd usr/bin ; ln -sf ../../bin/uname uname )
( cd usr/bin ; rm -rf mkfifo )
( cd usr/bin ; ln -sf ../../bin/mkfifo mkfifo )
( cd usr/bin ; rm -rf dircolors )
( cd usr/bin ; ln -sf ../../bin/dircolors dircolors )
( cd usr/man/man1 ; rm -rf ginstall.1.gz )
( cd usr/man/man1 ; ln -sf install.1.gz ginstall.1.gz )
( cd usr/sbin ; rm -rf chroot )
( cd usr/sbin ; ln -sf ../bin/chroot chroot )
( cd usr/share/locale/be/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/be/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ca/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ca/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/da/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/da/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/de/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/de/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/cs/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/cs/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/el/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/el/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/es/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/es/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/et/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/et/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/fi/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/fi/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/fr/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/fr/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/gl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/gl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/hu/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/hu/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ja/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ja/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/it/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/it/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ko/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ko/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/lg/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/lg/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/nb/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/nb/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ms/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ms/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/nl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/nl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/no/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/no/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pt/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pt/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ru/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ru/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sk/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sk/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sv/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sv/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/tr/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/tr/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pt_BR/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pt_BR/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/zh_CN/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/zh_CN/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/zh_TW/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/zh_TW/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )

==> coreutils-5.2.1-i486-1.tgz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/DIR_COLORS.new
( cd usr/bin ; rm -rf dd )
( cd usr/bin ; ln -sf ../../bin/dd dd )
( cd usr/bin ; rm -rf cp )
( cd usr/bin ; ln -sf ../../bin/cp cp )
( cd usr/bin ; rm -rf df )
( cd usr/bin ; ln -sf ../../bin/df df )
( cd usr/bin ; rm -rf du )
( cd usr/bin ; ln -sf ../../bin/du du )
( cd usr/bin ; rm -rf ln )
( cd usr/bin ; ln -sf ../../bin/ln ln )
( cd usr/bin ; rm -rf ls )
( cd usr/bin ; ln -sf ../../bin/ls ls )
( cd usr/bin ; rm -rf mv )
( cd usr/bin ; ln -sf ../../bin/mv mv )
( cd usr/bin ; rm -rf rm )
( cd usr/bin ; ln -sf ../../bin/rm rm )
( cd usr/bin ; rm -rf cat )
( cd usr/bin ; ln -sf ../../bin/cat cat )
( cd usr/bin ; rm -rf cut )
( cd usr/bin ; ln -sf ../../bin/cut cut )
( cd usr/bin ; rm -rf pwd )
( cd usr/bin ; ln -sf ../../bin/pwd pwd )
( cd usr/bin ; rm -rf ginstall )
( cd usr/bin ; ln -sf install ginstall )
( cd usr/bin ; rm -rf date )
( cd usr/bin ; ln -sf ../../bin/date date )
( cd usr/bin ; rm -rf echo )
( cd usr/bin ; ln -sf ../../bin/echo echo )
( cd usr/bin ; rm -rf head )
( cd usr/bin ; ln -sf ../../bin/head head )
( cd usr/bin ; rm -rf stty )
( cd usr/bin ; ln -sf ../../bin/stty stty )
( cd usr/bin ; rm -rf sync )
( cd usr/bin ; ln -sf ../../bin/sync sync )
( cd usr/bin ; rm -rf true )
( cd usr/bin ; ln -sf ../../bin/true true )
( cd usr/bin ; rm -rf chgrp )
( cd usr/bin ; ln -sf ../../bin/chgrp chgrp )
( cd usr/bin ; rm -rf chmod )
( cd usr/bin ; ln -sf ../../bin/chmod chmod )
( cd usr/bin ; rm -rf chown )
( cd usr/bin ; ln -sf ../../bin/chown chown )
( cd usr/bin ; rm -rf false )
( cd usr/bin ; ln -sf ../../bin/false false )
( cd usr/bin ; rm -rf mkdir )
( cd usr/bin ; ln -sf ../../bin/mkdir mkdir )
( cd usr/bin ; rm -rf mknod )
( cd usr/bin ; ln -sf ../../bin/mknod mknod )
( cd usr/bin ; rm -rf rmdir )
( cd usr/bin ; ln -sf ../../bin/rmdir rmdir )
( cd usr/bin ; rm -rf shred )
( cd usr/bin ; ln -sf ../../bin/shred shred )
( cd usr/bin ; rm -rf sleep )
( cd usr/bin ; ln -sf ../../bin/sleep sleep )
( cd usr/bin ; rm -rf touch )
( cd usr/bin ; ln -sf ../../bin/touch touch )
( cd usr/bin ; rm -rf uname )
( cd usr/bin ; ln -sf ../../bin/uname uname )
( cd usr/bin ; rm -rf mkfifo )
( cd usr/bin ; ln -sf ../../bin/mkfifo mkfifo )
( cd usr/bin ; rm -rf dircolors )
( cd usr/bin ; ln -sf ../../bin/dircolors dircolors )
( cd usr/man/man1 ; rm -rf ginstall.1.gz )
( cd usr/man/man1 ; ln -sf install.1.gz ginstall.1.gz )
( cd usr/sbin ; rm -rf chroot )
( cd usr/sbin ; ln -sf ../bin/chroot chroot )
( cd usr/share/locale/af/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/af/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/be/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/be/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ca/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ca/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/da/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/da/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/de/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/de/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/cs/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/cs/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/el/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/el/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/es/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/es/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/et/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/et/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/fi/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/fi/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ga/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ga/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/fr/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/fr/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/gl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/gl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/hu/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/hu/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ja/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ja/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/it/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/it/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ko/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ko/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/lg/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/lg/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/nb/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/nb/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ms/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ms/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/nl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/nl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/no/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/no/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pt/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pt/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/ru/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/ru/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sk/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sk/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sl/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sl/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/sv/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/sv/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/tr/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/tr/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/pt_BR/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/pt_BR/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/zh_CN/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/zh_CN/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
( cd usr/share/locale/zh_TW/LC_TIME ; rm -rf coreutils.mo )
( cd usr/share/locale/zh_TW/LC_TIME ; ln -sf ../LC_MESSAGES/coreutils.mo coreutils.mo )
